from django.shortcuts import render, redirect
from admin_gradient.forms import RegistrationForm,LoginForm,UserPasswordResetForm,UserSetPasswordForm,UserPasswordChangeForm
from django.contrib.auth import views as auth_views
from django.contrib.auth import logout

from django.contrib.auth.decorators import login_required

def auth_signup(request):
  if request.method == 'POST':
      form = RegistrationForm(request.POST)
      if form.is_valid():
        form.save()
        print('Account created successfully!')
        return redirect('/accounts/auth-signin/')
      else:
        print("Registration failed!")
  else:
    form = RegistrationForm()
  context = {'form': form}
  return render(request, 'accounts/auth-signup.html', context)

class AuthSignin(auth_views.LoginView):
  template_name = 'accounts/auth-signin.html'
  form_class = LoginForm
  success_url = '/'

class UserPasswordResetView(auth_views.PasswordResetView):
  template_name = 'accounts/forgot-password.html'
  form_class = UserPasswordResetForm

class UserPasswordResetConfirmView(auth_views.PasswordResetConfirmView):
  template_name = 'accounts/recover-password.html'
  form_class = UserSetPasswordForm

class UserPasswordChangeView(auth_views.PasswordChangeView):
  template_name = 'accounts/password_change.html'
  form_class = UserPasswordChangeForm

class UserPasswordResetConfirmView(auth_views.PasswordResetConfirmView):
  template_name = 'accounts/recover-password.html'
  form_class = UserSetPasswordForm

class UserPasswordChangeView(auth_views.PasswordChangeView):
  template_name = 'accounts/password_change.html'
  form_class = UserPasswordChangeForm

def user_logout_view(request):
  logout(request)
  return redirect('/accounts/auth-signin/')


# Dashboard
def index(request):
    return render(request, 'pages/index.html')

# UI Element
@login_required(login_url='/accounts/auth-signin')
def bc_typography(request):
    return render(request, 'pages/bc_typography.html')

@login_required(login_url='/accounts/auth-signin')
def icon_feather(request):
    return render(request, 'pages/icon-feather.html')

# Table
@login_required(login_url='/accounts/auth-signin')
def tbl_bootstrap(request):
    return render(request, 'pages/tbl_bootstrap.html')

# Chart & Maps
@login_required(login_url='/accounts/auth-signin')
def chart_apex(request):
    return render(request, 'pages/chart-apex.html')

@login_required(login_url='/accounts/auth-signin')
def map_google(request):
    return render(request, 'pages/map-google.html')

# Pages

@login_required(login_url='/accounts/auth-signin')
def user_profile(request):
    return render(request, 'pages/user-profile.html')
    
@login_required(login_url='/accounts/auth-signin')
def sample_page(request):
    return render(request, 'pages/sample-page.html')



# -*- encoding: utf-8 -*-
"""
Copyright (c) 2019 - present AppSeed.us
"""

from django.apps import AppConfig

class AdminGradientConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'admin_gradient'


from django.urls import path
from admin_gradient import views
from django.contrib.auth import views as auth_views

urlpatterns = [
    #pages
    path('', views.index, name = 'index'),
    path('bc-typography/', views.bc_typography, name = 'bc_typography'),
    path('icon-feather/', views.icon_feather, name = 'icon_feather'),
    path('tbl-bootstrap/', views.tbl_bootstrap, name = 'tbl_bootstrap'),
    path('chart-apex/', views.chart_apex, name = 'chart_apex'),
    path('map-google/', views.map_google, name = 'map_google'),
    path('sample-page/', views.sample_page, name = 'sample_page'),
    path('user-profile/', views.user_profile, name = 'user_profile'),
    path('accounts/auth-signup/', views.auth_signup, name = 'auth_signup'),
    path('accounts/auth-signin/', views.AuthSignin.as_view(), name='auth_signin'),
    path('accounts/forgot-password/', views.UserPasswordResetView.as_view(), name='forgot_password'),
    path('accounts/password-reset-done/', auth_views.PasswordResetDoneView.as_view(
        template_name='accounts/password_reset_done.html'
    ), name='password_reset_done'),
    path('accounts/password-reset-confirm/<uidb64>/<token>/', 
        views.UserPasswordResetConfirmView.as_view(), name='password_reset_confirm'),
    path('accounts/password-reset-complete/', auth_views.PasswordResetCompleteView.as_view(
        template_name='accounts/password_reset_complete.html'
    ), name='password_reset_complete'),
    path('accounts/logout/', views.user_logout_view, name='logout'),
    path('accounts/password-change/', views.UserPasswordChangeView.as_view(), name='password_change'),
    path('accounts/password-change-done/', auth_views.PasswordChangeDoneView.as_view(
        template_name='accounts/password_change_done.html'
    ), name="password_change_done" ),
]
